Prerequisites
-------------
Panda3D installed into system python, on Linux, Windows or OSX.

In virtualenv
-------------

Make sure pip and setuptools are up to date

(my-virtualenv) $ pip install -U pip setuptools

Allow virtualenv to access Panda3D

(my-virtualenv) $ pip install vext.panda3d


Reporting Bugs
--------------

Report bugs to the [vext project](//github.com/stuaxo/vext/issues)


This is *Experimental* I haven't used Panda3d much, feedback, patches welcome :)
